@@ -1,6 +1,6 @@
 """Contains the DB wrapper class."""
 from contextlib import asynccontextmanager
-from logging import Logger, getLogger
+from logging import Logger
 from typing import Any, AsyncIterator, Callable, Iterable, List, Optional, cast
 
 from asyncpg import Connection, connect
