@@ -1,7 +1,7 @@
 """Shared types."""
 from typing import Any, List, Mapping, Optional, Tuple, Union
 
-ConnectionArgs = Union[Mapping[str, str], str]
+ConnectionArgs = Union[Mapping[str, Any], str]
 
 InsertAssignments = Union[
     Mapping[str, Any],
